@@ -5,7 +5,7 @@
  *  open source, and has the attribution requirements (GPL Section 7) at
  *  http://statnet.org/attribution
  *
- *  Copyright 2008-2016 Statnet Commons
+ *  Copyright 2008-2018 Statnet Commons
  */
 #include "wtchangestats_rank.h"
 
@@ -879,3 +879,52 @@ WtS_CHANGESTAT_FN(s_localAND_nonconformity){
 }
 
 
+
+WtD_FROM_S_FN(d_nonconformity_decay)
+
+WtS_CHANGESTAT_FN(s_nonconformity_decay){ 
+  CHANGE_STAT[0]=0;
+  for(Vertex v1=1; v1 <= N_NODES; v1++){
+    for(Vertex v2=1; v2 <= N_NODES; v2++){
+      if(v2==v1) continue;
+      double e = pow(INPUT_PARAM[1],INPUT_PARAM[0]-GETWT(v1,v2));
+      for(Vertex v3=1; v3 <= N_NODES; v3++){
+	if(v3==v2 || v3==v1) continue;
+	double v13=GETWT(v1,v3), v23=GETWT(v2,v3);
+	for(Vertex v4=1; v4 <= N_NODES; v4++){
+	  if(v4==v3 || v4==v2 || v4==v1) continue;
+	  unsigned int
+	    v134 = v13>GETWT(v1,v4),
+	    v234 = v23>GETWT(v2,v4);
+	  if(v134!=v234) CHANGE_STAT[0]+=e;
+	}
+      }
+    }
+  }
+}
+
+WtD_FROM_S_FN(d_nonconformity_thresholds)
+
+WtS_CHANGESTAT_FN(s_nonconformity_thresholds){ 
+  ZERO_ALL_CHANGESTATS();
+  for(Vertex v1=1; v1 <= N_NODES; v1++){
+    for(Vertex v2=1; v2 <= N_NODES; v2++){
+      if(v2==v1) continue;
+      double v12 = GETWT(v1,v2);
+      unsigned int i;
+      for(i=0; i<N_CHANGE_STATS; i++) if(v12>=INPUT_PARAM[i]) break;
+      if(i==N_CHANGE_STATS) continue;
+      for(Vertex v3=1; v3 <= N_NODES; v3++){
+	if(v3==v2 || v3==v1) continue;
+	double v13=GETWT(v1,v3), v23=GETWT(v2,v3);
+	for(Vertex v4=1; v4 <= N_NODES; v4++){
+	  if(v4==v3 || v4==v2 || v4==v1) continue;
+	  unsigned int
+	    v134 = v13>GETWT(v1,v4),
+	    v234 = v23>GETWT(v2,v4);
+	  if(v134!=v234) CHANGE_STAT[i]+=1;
+	}
+      }
+    }
+  }
+}
